@@ -1,4 +1,7 @@
 """
+Page middleware (``feincms3.incubator.root``)
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
 The guide recommends using a view for the feincms3 pages app. However, using
 catch-all URLs together with ``i18n_patterns`` leads to the strange behavior
 where 404-errors always lead to a redirect if the URL doesn't begin with a
@@ -24,41 +27,52 @@ Example code for using this module (e.g. ``app.pages.middleware``):
     # The page handler receives the request and the page.
     # ``add_redirect_handler`` wraps the handler function with support for the
     # RedirectMixin.
-    handler = add_redirect_handler(
-        lambda request, page: render(
-            request, page.type.template_name, page_context(request, page=page)
-        )
-    )
+    @add_redirect_handler
+    def handler(request, page):
+        return render(request, page.type.template_name, page_context(request, page=page))
 
     # This is the middleware which you want to add to ``MIDDLEWARE`` as
     # ``app.pages.middleware.page_if_404_middleware``. The middleware should be
     # added in the last position except if you have a very good reason not to
     # do this.
     page_if_404_middleware = create_page_if_404_middleware(
+        # queryset=Page.objects.active() works too (if .active() doesn't use
+        # get_language or anything similar)
         queryset=lambda request: Page.objects.active(),
+
         handler=handler,
     )
-
-You'll also have to override the ``get_absolute_url`` method on your page
-class because the default method uses ``reverse()``:
-
-.. code-block:: python
-
-    class Page(AbstractPage, ...):
-        def get_absolute_url(self):
-            return path_with_script_prefix(self.path)
 """
 
+from functools import wraps
+
 from django.http import HttpResponseRedirect
-from django.urls import get_script_prefix
-from django.utils.encoding import iri_to_uri
 
 
-def path_with_script_prefix(path):
-    return iri_to_uri(get_script_prefix().rstrip("/") + path)
+def create_page_if_404_middleware(*, queryset, handler, language_code_redirect=False):
+    """
+    Create a middleware for handling pages
 
+    This utility is there for your convenience, you do not have to use it. The
+    returned middleware already handles returning non-404 responses as-is,
+    fetching a page instance from the database and calling a user-defined
+    handler on success. It optionally also supports redirecting requests to the
+    root of the app to a language-specific landing page.
+
+    Required arguments:
+
+    - ``queryset``: A page queryset or a callable accepting the request and
+      returning a page queryset.
+    - ``handler``: A callable accepting the request and a page and returning a
+      response.
+
+    Optional arguments:
+
+    - ``language_code_redirect`` (``False``): Redirect visitor to the language
+      code prefix (e.g. ``/en/``, ``/de-ch/``) if request path equals the
+      script prefix (generally ``/``) and no active page for ``/`` exists.
+    """
 
-def create_page_if_404_middleware(*, queryset, handler, language_code_redirect=True):
     def outer(get_response):
         def inner(request):
             response = get_response(request)
@@ -79,6 +93,11 @@ def create_page_if_404_middleware(*, queryset, handler, language_code_redirect=T
 
 
 def add_redirect_handler(handler):
+    """
+    Wrap the page handler in a redirect mixin handler
+    """
+
+    @wraps(handler)
     def inner(request, page):
         if redirect_to := page.get_redirect_url():
             return HttpResponseRedirect(redirect_to)
