@@ -1,4 +1,7 @@
 """
+Passthru page apps (``feincms3.incubator.root_passthru``)
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
 The idea of this module is to allow tagging pages to allow programmatically
 determing the URL of pages which are often linked to, e.g. privacy policy or
 imprint pages.
@@ -22,7 +25,14 @@ Reverse the URL of the page (if it exists):
 
 .. code-block:: python
 
+    # Raise NoReverseMatch on failure
     reverse_passthru("imprint")
+
+    # Fallback
+    reverse_passthru("imprint", fallback="/en/imprint/")
+
+    # Outside the request-response cycle
+    reverse_passthru("imprint", urlconf=apps_urlconf())
 """
 
 from django.http import HttpResponseNotFound
@@ -35,12 +45,17 @@ app_name = "passthru"
 urlpatterns = [
     path(
         "",
-        # Run page_if_404_middleware
+        # Trigger the page_if_404_middleware
         lambda request: HttpResponseNotFound(),
         name="passthru",
     ),
 ]
 
 
-def reverse_passthru(namespace):
-    return reverse_app(namespace, "passthru")
+def reverse_passthru(namespace, **kwargs):
+    """
+    Reverse a passthru app URL
+
+    Raises ``NoReverseMatch`` if page could not be found.
+    """
+    return reverse_app(namespace, "passthru", **kwargs)
