@@ -1,25 +1,25 @@
 /* global CKEDITOR, django */
-(function () {
+;(function () {
   function onReady(fn) {
     if (
       document.readyState === "complete" ||
       document.readyState === "interactive"
     ) {
       // call on next available tick
-      setTimeout(fn, 1);
+      setTimeout(fn, 1)
     } else {
-      document.addEventListener("DOMContentLoaded", fn);
+      document.addEventListener("DOMContentLoaded", fn)
     }
   }
 
   onReady(function () {
-    const configs = {};
-    const scripts = document.querySelectorAll("[data-inline-cke-config]");
+    const configs = {}
+    const scripts = document.querySelectorAll("[data-inline-cke-config]")
     scripts.forEach(function parseConfig(script) {
       configs[script.dataset.inlineCkeId] = JSON.parse(
         script.dataset.inlineCkeConfig
-      );
-    });
+      )
+    })
 
     function initializeInlineCKE() {
       document.querySelectorAll("textarea[data-inline-cke]").forEach((el) => {
@@ -27,20 +27,20 @@
           el.dataset.inlineCke !== "active" &&
           !el.id.includes("__prefix__")
         ) {
-          CKEDITOR.inline(el, configs[el.dataset.inlineCke]);
-          el.dataset.inlineCke = "active";
+          CKEDITOR.inline(el, configs[el.dataset.inlineCke])
+          el.dataset.inlineCke = "active"
         }
-      });
+      })
     }
 
     function addFormsetAddedHandler() {
-      django.jQuery(document).on("formset:added", initializeInlineCKE);
+      django.jQuery(document).on("formset:added", initializeInlineCKE)
     }
 
-    initializeInlineCKE();
+    initializeInlineCKE()
 
     if (window.django) {
-      addFormsetAddedHandler();
+      addFormsetAddedHandler()
     }
-  });
-})();
+  })
+})()
